from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class TCPOptimization(object):
    """
    Real-Time Monitoring - TCP Optimization API
    
    Implements GET POST DEL PUT methods for TCPOptimization endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getActiveTCPFlows(self, deviceId):
        """
        Get TCP optimized active flows from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tcpopt/activeflows?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getExpiredTCPFlows(self, deviceId):
        """
        Get TCP optimized expired flows from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tcpopt/expiredflows?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTCPSummary(self, deviceId):
        """
        Get TCP optimization summary from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/tcpopt/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DPI(object):
    """
    Monitoring - DPI API
    
    Implements GET POST DEL PUT methods for DPI endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, statsquerystring):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getPostAggregationAppData(self, queryfilter):
        """
        Get raw aggregated data and display applications with the highest utilization for a device
        
        Parameters:
        queryfilter:	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/agg-app/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, queryfilter)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationData(self, queryfilter):
        """
        Get raw aggregated data and display applications with the highest utilization for a device
        
        Parameters:
        queryfilter:	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, queryfilter)
        return response


    def createDPIFlowsGridListQuery(self, query, limit):
        """
        Get detailed DPI application flows list in a grid table
        
        Parameters:
        query	 (string):	Query string
		limit	 (string):	Query size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/applications?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDPISummary(self, query, limit):
        """
        Get detailed DPI application flows summary
        
        Parameters:
        query	 (string):	Query string
		limit	 (string):	Query size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/applications/summary?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getUniqueFlowCount(self, deviceId, interval, application, window, family):
        """
        Get application flow count per tunnel
        
        Parameters:
        deviceId	 (string):	Device Id
		interval	 (string):	Interval
		application	 (string):	Application
		window	 (string):	Window
		family	 (string):	Family
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/device/application/flowcount?deviceId={deviceId}&interval={interval}&application={application}&window={window}&family={family}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDPIDeviceGridData(self, query, limit):
        """
        Get detailed DPI flows list
        
        Parameters:
        query	 (string):	Query string
		limit	 (string):	Query size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/device/applications?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDPIDeviceAndAppDetails(self, query):
        """
        Get detailed DPI device and app list
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/device/details/applications?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, statsquerystring, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getAggregationDataForPacketDup(self, querystring):
        """
        Get time series aggregation data for packet duplication for an application over TLOCs if available
        
        Parameters:
        querystring:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/pktdup/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, querystring)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAggregationDataDPI(self, querystring):
        """
        Get aggregation data and fec recovery rate if available
        
        Parameters:
        querystring:	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/dpi/recovery/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, querystring)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Deployer(object):
    """
    Deployment Mode API
    
    Implements GET POST DEL PUT methods for DeploymentMode endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def requestDNSSecActions(self, action):
        """
        Request DNS-Sec actions
        
        Parameters:
        action	 (string):	DNS-Sec action
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/dnssec/actions?action={action}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def configureDNSSec(self, request):
        """
        Configure DNS-Sec
        
        Parameters:
        request:	DNS sec config request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/dnssec/config"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def getDNSSecStatus(self):
        """
        Get DNS-Sec status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/dnssec/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def configFedrampMode(self, mode):
        """
        Set network deployment mode
        
        Parameters:
        mode:	Network deployment mode
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/status"
        response = self.client.apiCall(HttpMethods.POST, endpoint, mode)
        return response


    def requestWazuhActions(self, action):
        """
        Wazuh agent action
        
        Parameters:
        action	 (string):	Wazhuh Action
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/wazuh/actions?action={action}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def configureWazuhClient(self, wazhuhConfig):
        """
        Configure Wazuh agent
        
        Parameters:
        wazhuhConfig:	Wazhuh configuration
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/wazuh/config"
        response = self.client.apiCall(HttpMethods.POST, endpoint, wazhuhConfig)
        return response


    def getWazuhAgentStatus(self):
        """
        Get Wazuh agent status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/fedramp/wazuh/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class User(object):
    """
    Administration - User and Group API
    
    Implements GET POST DEL PUT methods for UserandGroup endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    def getColoGroups(self):
        """
        Get COLO groups
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/cologroup"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createColoGroup(self, colocationgroup):
        """
        Add COLO group
        
        Parameters:
        colocationgroup:	Colocation group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/cologroup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, colocationgroup)
        return response


    def editColoGroup(self, colocationgroup, id):
        """
        Update COLO group
        
        Parameters:
        colocationgroup:	Colocation group
		id	 (string):	Colocation group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/cologroup/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, colocationgroup)
        return response


    def deleteColoGroup(self, id):
        """
        Delete COLO group
        
        Parameters:
        id	 (string):	Colocation group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/cologroup/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getResourceGroups(self):
        """
        Get all groups
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/resourcegroup"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createResourceGroup(self, createagroup):
        """
        Create a group
        
        Parameters:
        createagroup:	Create a group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/resourcegroup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, createagroup)
        return response


    def switchView(self, groupView):
        """
        Global netadmin switches to a different resource group view
        
        Parameters:
        groupView:	Global netadmin switches to a different resource group view
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/resourcegroup/switch"
        response = self.client.apiCall(HttpMethods.POST, endpoint, groupView)
        return response


    def editResourceGroup(self, updategroupdescription, groupId):
        """
        Update a group
        
        Parameters:
        groupdesc:  (string)	Update group description
		groupId:    (string)    Resource group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/resourcegroup/{groupId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, updategroupdescription)
        return response


    def deleteResourceGroup(self, groupId):
        """
        Delete a group
        
        Parameters:
        groupId:    (string)    Resource group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/resourcegroup/{groupId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def findUsers(self):
        """
        Get all users
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createUser(self, user):
        """
        Create a user
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user"
        response = self.client.apiCall(HttpMethods.POST, endpoint, user)
        return response


    def getActiveSessions(self):
        """
        Get active sessions
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/activeSessions"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateAdminPassword(self, user):
        """
        Update admin default password
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/admin/password"
        response = self.client.apiCall(HttpMethods.POST, endpoint, user)
        return response


    def validatePassword(self, userpassword):
        """
        Validate user password
        
        Parameters:
        userpassword:	User password
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/password/validate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, userpassword)
        return response


    def updatePassword(self, user, userName):
        """
        Update user password
        
        Parameters:
        user:	User
		userName	 (string):	User name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/password/{userName}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, user)
        return response


    def updateProfileLocale(self, user):
        """
        Update profile locale
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/profile/locale"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, user)
        return response


    def updateProfilePassword(self, user):
        """
        Update profile password
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/profile/password"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, user)
        return response


    def removeSessions(self, user):
        """
        Remove sessions
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/removeSessions"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, user)
        return response


    def resetUser(self, user):
        """
        Unlock a user
        
        Parameters:
        user:	User
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/reset"
        response = self.client.apiCall(HttpMethods.POST, endpoint, user)
        return response


    def resourceGroupName(self):
        """
        Get the name of the resource group associated with the current logged in user
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/resourceGroupName"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findUserRole(self):
        """
        Check whether a user has admin role
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/role"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findUserAuthType(self):
        """
        Find user authentication type, whether it is SAML enabled
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/userAuthType"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateUser(self, user, userName):
        """
        Update user
        
        Parameters:
        user:	                User
		userName	 (string):	User name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/{userName}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, user)
        return response


    def deleteUser(self, userName):
        """
        Delete user
        
        Parameters:
        userName	 (string):	User name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/user/{userName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def findUserGroups(self):
        """
        Get all user groups
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createUserGroup(self, usergroup):
        """
        Create user group
        
        Parameters:
        usergroup:	User group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, usergroup)
        return response


    def createGroupGridColumns(self):
        """
        Get user groups in a grid table
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup/definition"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findUserGroupsAsKeyValue(self):
        """
        Get user groups as key value map
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup/keyvalue"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateUserGroup(self, usergroup, userGroupId):
        """
        Update user group
        
        Parameters:
        usergroup:	            User group
		userGroupId	 (string):	User group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup/{userGroupId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, usergroup)
        return response


    def deleteUserGroup(self, userGroupId):
        """
        Delete user group
        
        Parameters:
        userGroupId	 (string):	User group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/usergroup/{userGroupId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getVpnGroups(self):
        """
        Get VPN groups
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/vpngroup"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createVpnGroup(self, vpngroup):
        """
        Add VPN group
        
        Parameters:
        vpngroup:	VPN group
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/vpngroup"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vpngroup)
        return response


    def editVpnGroup(self, vpngroup, id):
        """
        Update VPN group
        
        Parameters:
        vpngroup:	VPN group
		id	 (string):	VPN group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/vpngroup/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, vpngroup)
        return response


    def deleteVpnGroup(self, id):
        """
        Delete VPN group
        
        Parameters:
        id	 (string):	VPN group Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/admin/vpngroup/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class System(object):
    """
    Real-Time Monitoring - System API
    
    Implements GET POST DEL PUT methods for System endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getNativeInfo(self, deviceId):
        """
        Get device system native settings from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/csp/system/native?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProcessList(self, deviceId):
        """
        Get device system process list from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/csp/system/processlist?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSetting(self, deviceId):
        """
        Get device system settings from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/csp/system/settings?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatus(self, deviceId):
        """
        Get device system status from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/csp/system/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInfoList(self, deviceId):
        """
        Get device information list
        
        Parameters:
        deviceId	 (array):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/system/info?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStats(self, deviceId):
        """
        Get device system stats list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/system/statistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatusList(self, deviceId):
        """
        Get device system status list (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/system/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncedStatusList(self, deviceId):
        """
        Get device system stats list synchronously
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/system/synced/status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Audit(object):
    """
    Administration - Audit Log API
    
    Implements GET POST DEL PUT methods for AuditLog endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getStatDataRawAuditLogData(self, inputQuery):
        """
        Get stat raw data
        
        Parameters:
        inputQuery	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog?inputQuery={inputQuery}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRawPropertyData(self, query):
        """
        Get raw property data with post action
        
        Parameters:
        query:	Query filter for getting stat raw data
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPropertyAggregationData(self, inputQuery):
        """
        Get raw property data aggregated
        
        Parameters:
        inputQuery	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/aggregation?inputQuery={inputQuery}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostPropertyAggregationData(self, query):
        """
        Get raw property data aggregated with post action
        
        Parameters:
        query:	Query filter for getting stat raw data
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawPropertyData(self, inputQuery, scrollId, count):
        """
        Get raw property data in bulk
        
        Parameters:
        inputQuery	 (string):	Query filter
		scrollId	 (string):	Offset of the query result
		count	 (string):	size of the query result
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/page?inputQuery={inputQuery}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawPropertyData(self, query, scrollId, count):
        """
        Get raw property data in bulk with post action
        
        Parameters:
        query:	Query filter for getting stat raw data
		scrollId	 (string):	Offset of the query result
		count	 (string):	Size of the query result
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateAuditLog(self, query):
        """
        Get audit logs for last 3 hours
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/severity?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAuditSeverityCustomHistogram(self, query):
        """
        Get audit log severity histogram
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/auditlog/severity/summary?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Dashboard(object):
    """
    Configuration - Dashboard Status API
    
    Implements GET POST DEL PUT methods for DashboardStatus endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def cancelPending(self, processId):
        """
        Bulk cancel task status
        
        Parameters:
        processId	 (string):	Process Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/cancel/{processId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def cleanStatus(self, cleanStatus):
        """
        Delete task and status vertex
        
        Parameters:
        cleanStatus	 (boolean):	Clear status flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/clean?cleanStatus={cleanStatus}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteStatus(self, processId):
        """
        Delete status of action
        
        Parameters:
        processId	 (string):	Process Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/clear?processId={processId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def findRunning(self):
        """
        Find running tasks
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/tasks"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getActiveCount(self):
        """
        Get active task count
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/tasks/activeCount"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCleanStatus(self, processId):
        """
        Delete task and status vertex
        
        Parameters:
        processId	 (string):	Process Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/tasks/clean?processId={processId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findStatus(self, actionName):
        """
        Find status of action
        
        Parameters:
        actionName	 (string):	Action name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/status/{actionName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Settings(object):
    """
    Configuration - Settings API
    
    Implements GET POST DEL PUT methods for Settings endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getBanner(self):
        """
        Retrieve banner
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/banner"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSessionTimout(self):
        """
        Get client session timeout
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/clientSessionTimeout"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createAnalyticsDataFile(self):
        """
        Create analytics data file
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/analytics/dca"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getCertConfig(self, settingType):
        """
        Retrieve certificate configuration value by settingType
        
        Parameters:
        settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/certificate/{settingType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editCertConfig(self, certConfig, settingType):
        """
        Update certificate configuration
        
        Parameters:
        certConfig:	Certificate config
		settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/certificate/{settingType}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, certConfig)
        return response


    def newCertConfig(self, certConfig, settingType):
        """
        Add new certificate configuration
        
        Parameters:
        certConfig:	Certificate config
		settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/certificate/{settingType}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certConfig)
        return response


    def getGoogleMapKey(self):
        """
        Retrieve Google map key
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/googleMapKey"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMaintenanceWindow(self):
        """
        Retrieve maintenance window
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/maintenanceWindow"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConfigBySettingType(self, settingType):
        """
        Retrieve configuration value by settingType
        
        Parameters:
        settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/{settingType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editConfig(self, configSetting, settingType):
        """
        Update configuration setting
        
        Parameters:
        configSetting:	Configuration setting
		settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/{settingType}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, configSetting)
        return response


    def newConfig(self, configSetting, settingType):
        """
        Add new configuration
        
        Parameters:
        configSetting:	Configuration setting
		settingType	 (string):	Setting type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/settings/configuration/{settingType}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, configSetting)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Inventory(object):
    """
    Configuration - Device Inventory API
    
    Implements GET POST DEL PUT methods for DeviceInventory endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def createDevice(self, createdevicerequest):
        """
        Create new device
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        createdevicerequest:	Create device request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device"
        response = self.client.apiCall(HttpMethods.POST, endpoint, createdevicerequest)
        return response


    def generateBootstrapConfigForVedge(self, uuid, configtype, inclDefRootCert, version):
        """
        Create vEdge device config
        
        Parameters:
        uuid	 (string):	Device uuid
		configtype	 (string):	Device config type
		inclDefRootCert	 (boolean):	Include default root certs flag
		version	 (string):	cloud-init format version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/bootstrap/device/{uuid}?configtype={configtype}&inclDefRootCert={inclDefRootCert}&version={version}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateBootstrapConfigForVedges(self, devicebootstraptypeandid):
        """
        Create bootstrap config for software vEdges
        
        Parameters:
        devicebootstraptypeandid:	Device bootstrap type and id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/bootstrap/devices"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicebootstraptypeandid)
        return response


    def getBootstrapConfigZip(self, id):
        """
        Download vEdge device config
        
        Parameters:
        id	 (string):	Bootstrap config id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/bootstrap/download/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateGenericBootstrapConfigForVedges(self, wanif):
        """
        Create bootstrap config for software vEdges
        
        Parameters:
        wanif	 (string):	Device WAN interface
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/bootstrap/generic/devices?wanif={wanif}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def claimDevices(self, claimdevicerequest):
        """
        Claim the selected unclaimed devices
        
        Parameters:
        claimdevicerequest:	Claim device request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/claimDevices"
        response = self.client.apiCall(HttpMethods.POST, endpoint, claimdevicerequest)
        return response


    def getControllerVEdgeSyncStatus(self):
        """
        Get controllers vEdge sync status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/controllers/vedge/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def decommissionVedgeCloud(self, uuid):
        """
        Decomission vEdge device
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/decommission/{uuid}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def devicesWithoutSubjectSudi(self):
        """
        retrieve devices without subject sudi
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/devicesWithoutSubjectSudi"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def formPost(self):
        """
        Upload file to vEdge
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/fileupload"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def validateUser(self, bodyParameter):
        """
        Authenticate vSmart user account
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/generate-payg"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def setLifeCycle(self, uuid, enable):
        """
        Set device lifecycle needed flag
        
        Parameters:
        uuid	 (string):	Device uuid
		enable	 (boolean):	lifecycle needed flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/lifecycle/management/{uuid}?enable={enable}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getManagementSystemIPInfo(self):
        """
        Get management system IP mapping
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/management/systemip"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def migrateDevice(self, uuid):
        """
        Migrate device software to vedge/cedge
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/migrateDevice/{uuid}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def resetVedgeCloud(self, uuid):
        """
        Reset vEdge device
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/reset/{uuid}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def getRMACandidates(self, deviceType, uuid):
        """
        Get RMA candidates by device type
        
        Parameters:
        deviceType	 (string):	Device Type
		uuid	 (string):	Excluded currently selected uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/rma/candidates/{deviceType}?uuid={uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRootCertStatusAll(self, state):
        """
        Get controllers vEdge sync status
        
        Parameters:
        state	 (string):	Root certificate state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/rootcertchain/status?state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def checkSelfSignedCert(self):
        """
        Whether self signed certificate created
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/selfsignedcert/iscreated"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def validateUser(self, bodyParameter):
        """
        Authenticate vSmart user account
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/smartaccount/authenticate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def syncDevices(self, bodyParameter):
        """
        Sync devices from Smart-Account
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/smartaccount/sync"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def syncRootCertChain(self):
        """
        Sync root certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/sync/rootcertchain"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTenantManagementSystemIPs(self):
        """
        Get management system IP
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/tenant/management/systemip"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudDockDataBasedOnDeviceType(self, deviceCategory):
        """
        Get devices details
        
        Parameters:
        deviceCategory	 (string):	Device category
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/type/{deviceCategory}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudDockDefaultConfigBasedOnDeviceType(self, deviceCategory):
        """
        Get devices default config
        
        Parameters:
        deviceCategory	 (string):	Device category
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/type/{deviceCategory}/defaultConfig"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllUnclaimedDevices(self):
        """
        Get list of all unclaimed devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/unclaimedDevices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def invalidateVmanageRootCA(self, uuid):
        """
        Invalidate vManage root CA
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/vmanagerootca/{uuid}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getDevicesDetails(self, deviceCategory, model, state, uuid, deviceIP, validity):
        """
        Get devices details. When {deviceCategory = controllers}, it returns vEdge sync status, vBond, vManage and vSmart.
When {deviceCategory = vedges}, it returns all available vEdge routers
        
        Parameters:
        deviceCategory	 (string):	Device category
		model	 (string):	Device model
		state	 (array):	List of states
		uuid	 (array):	List of device uuid
		deviceIP	 (array):	List of device system IP
		validity	 (array):	List of device validity
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/{deviceCategory}?model={model}&state={state}&uuid={uuid}&deviceIP={deviceIP}&validity={validity}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editDevice(self, deviceconfig, uuid):
        """
        Edit device
        
        Parameters:
        deviceconfig:	Device config
		uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/{uuid}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, deviceconfig)
        return response


    def deleteDevice(self, uuid):
        """
        Delete vEdges
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/device/{uuid}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class History(object):
    """
    Configuration - Device Config History API
    
    Implements GET POST DEL PUT methods for DeviceConfigHistory endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPostAggregationAppDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getLastThousandConfigList(self, deviceId, query):
        """
        Get device config history
        
        Parameters:
        deviceId	 (string):	Device Id
		query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/config?deviceId={deviceId}&query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConfigDiff(self, config_id1, config_id2):
        """
        Get diff of two configs
        
        Parameters:
        config_id1	 (string):	Config Id one
		config_id2	 (string):	Config Id two
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/config/diff/list?config_id1={config_id1}&config_id2={config_id2}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceConfig(self, config_id):
        """
        Get device config
        
        Parameters:
        config_id	 (string):	Config Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/config/{config_id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/history/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DataPrefixAll(object):
    """
    Configuration - Policy Data Prefix All Types Of Lists Builder API
    
    Implements GET POST DEL PUT methods for PolicyDataPrefixAllTypesOfListsBuilder endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getListsForAllDataPrefixes(self):
        """
        Get policy lists for all data prefixes
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(self, policylist):
        """
        Create policy list
        
        Parameters:
        policylist:	Policy list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policylist)
        return response


    def preview(self, policylist):
        """
        Preview a policy list based on the policy list type
        
        Parameters:
        policylist:	Policy list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall/preview"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policylist)
        return response


    def previewById(self, id):
        """
        Preview a specific policy list entry based on id provided
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall/preview/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getListsById(self, id):
        """
        Get a specific policy list based on the id
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def edit(self, policylist, id):
        """
        Edit policy list entries for a specific type of policy list
        
        Parameters:
        policylist:	Policy list
		id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policylist)
        return response


    def delete(self, id):
        """
        Delete policy list entry for a specific type of policy list
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/list/dataprefixall/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Device(object):
    """
    Configuration - Device Template API
    
    Implements GET POST DEL PUT methods for DeviceTemplate endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def pushMasterTemplate(self, devicetemplate):
        """
        Attach feature device template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachBootStrap"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def pushCLITemplate(self, devicetemplate):
        """
        Attach CLI device template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachcli"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def editCloudxConfig(self, cloudxconfig):
        """
        Edit already enabled gateways, clients, dias
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        cloudxconfig:	CloudX config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachcloudx"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, cloudxconfig)
        return response


    def pushCloudxConfig(self, cloudxconfig):
        """
        Enable gateways, clients, dias
        
        Parameters:
        cloudxconfig:	CloudX config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachcloudx"
        response = self.client.apiCall(HttpMethods.POST, endpoint, cloudxconfig)
        return response


    def getAttachedDeviceList(self, masterTemplateId):
        """
        Get attached device list by master template Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        masterTemplateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attached/{masterTemplateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAttachedConfigToDevice(self, deviceId):
        """
        Get attached config to device
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        deviceId	 (string):	Device Model ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachedconfig?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def pushMasterTemplate(self, devicetemplate):
        """
        Attach feature device template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachfeature"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def attachDeviceTemplate(self, devicetemplate):
        """
        Attach device template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/attachment"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def getDeviceListByMasterTemplateId(self, masterTemplateId):
        """
        Get possible device list by master template Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        masterTemplateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/available/{masterTemplateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceConfigurationPreview(self, devicetemplate):
        """
        Get device configuration
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/config"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def detachDeviceTemplate(self, devicetemplate):
        """
        Detach device template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/detach"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def detachSites(self, cloudxconfig):
        """
        Disable enabled gateways, clients, dias
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        cloudxconfig:	CloudX config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/detachcloudx"
        response = self.client.apiCall(HttpMethods.POST, endpoint, cloudxconfig)
        return response


    def getDevicesWithDuplicateIP(self, devicelist):
        """
        Detects duplicate system IP from a list of devices
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicelist:	Device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/duplicateip"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def createInputWithoutDevice(self, devicetemplate):
        """
        Export the device template to CSV format for given template id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/exportcsv"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def createDeviceInput(self, templatedeviceinput):
        """
        Create device input
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templatedeviceinput:	Template device input
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/input"
        response = self.client.apiCall(HttpMethods.POST, endpoint, templatedeviceinput)
        return response


    def processInputCommaSepFile(self, devicetemplate):
        """
        Process input comma separated file
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        devicetemplate:	Device template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/process/input/file"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicetemplate)
        return response


    def getQuickConnectVariables(self, devicelist):
        """
        Get connection variables to be configured
        
        Parameters:
        devicelist:	Device List
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/quickconnectvariable"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def checkVbond(self):
        """
        Check if vBond is configured
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/vbond"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def validateTemplate(self, payload):
        """
        Validate full template"

        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        payload:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/device/config/verify"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DRE(object):
    """
    Real-Time Monitoring - DRE API
    
    Implements GET POST DEL PUT methods for DRE endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getDreAutoBypassStats(self, ip, port, deviceId):
        """
        Get DRE auto-bypass statistics
        
        Parameters:
        ip	            (string):	Server IP
		port	        (number):	Port
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dre/auto-bypass-stats?appqoe-dre-auto-bypass-server-ip={ip}&appqoe-dre-auto-bypass-port={port}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDreStats(self, deviceId):
        """
        Get DRE statistics
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dre/dre-stats?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDreStatus(self, deviceId):
        """
        Get DRE status
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dre/dre-status?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDrePeerStats(self, ip, peerNo, deviceId):
        """
        Get DRE peer statistics
        
        Parameters:
        ip	 (string):	System IP
		peerNo	 (number):	Peer Number
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/dre/peer-stats?appqoe-dre-stats-peer-system-ip={ip}&appqoe-dre-stats-peer-peer-no={peerNo}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class ReverseProxy(object):
    """
    System - Reverse Proxy API
    
    Implements GET POST DEL PUT methods for Reverse Proxy endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def get(self, uuid):
        """
        Get reverse proxy IP/Port mappings for controller
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/reverseproxy/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(self, mapping, uuid):
        """
        Create reverse proxy IP/Port mappings for controller
        
        Parameters:
        mapping:	Device reverse proxy mappings
		uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/system/reverseproxy/{uuid}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, mapping)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class General(object):
    """
    Configuration - General Template API
    
    Implements GET POST DEL PUT methods for GeneralTemplate endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getFeatureTemplateList(self, summary, offset, limit):
        """
        Get feature template list
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        summary	 (boolean):	Flag to include template definition
		offset	 (integer):	Pagination offset
		limit	 (integer):	Pagination limit on templateId
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature?summary={summary}&offset={offset}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createFeatureTemplate(self, featuretemplate):
        """
        Create feature template
        
        Parameters:
        featuretemplate:	Feature template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature"
        response = self.client.apiCall(HttpMethods.POST, endpoint, featuretemplate)
        return response


    def cloneTemplate(self, id, name, desc):
        """
        Clone a feature template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        id	 (string):	Template Id to clone from
		name	 (string):	Name for the cloned template
		desc	 (string):	Description for the cloned template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/clone?id={id}&name={name}&desc={desc}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getNetworkInterface(self, deviceModel):
        """
        Get default network interface
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        deviceModel	 (string):	Device model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/default/networkinterface?deviceModel={deviceModel}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDefaultNetworks(self, deviceModel):
        """
        Get default networks
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        deviceModel	 (string):	Device model
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/default/networks?deviceModel={deviceModel}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplateDefinition(self, templateId):
        """
        Get the configured template definition for given template Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/definition/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceTemplatesAttachedToFeature(self, templateId):
        """
        Get all device templates for this feature template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Feature template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/devicetemplates/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def listLITemplate(self):
        """
        Get LI feature template
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/li"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLITemplate(self, litemplate):
        """
        Create LI feature template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        litemplate:	LI template
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/li"
        response = self.client.apiCall(HttpMethods.POST, endpoint, litemplate)
        return response


    def editLITemplate(self, litemplate, templateId):
        """
        Update LI feature template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        litemplate:	LI template
		templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/li/{templateId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, litemplate)
        return response


    def getMasterTemplateDefinition(self, type_name):
        """
        Generate template type definition by device type
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        type_name	 (string):	Device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/master/{type_name}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplateForMigration(self):
        """
        Generate a list of templates which require migration
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/migration"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getGeneralTemplate(self, templateId):
        """
        Get template object definition for given template Id
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/object/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def changeTemplateResourceGroup(self, templateId, resourceGroupName):
        """
        Change template resource group
        
        Parameters:
        templateId	 (string):	Template Id
		resourceGroupName	 (string):	Resrouce group name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/resource-group/{resourceGroupName}/{templateId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getTemplateTypes(self, type):
        """
        Generate template types
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        type	 (string):	Device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/types?type={type}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplateTypeDefinition(self, type_name, version):
        """
        Generate template type definition
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        type_name	 (string):	Device type
		version	 (string):	Version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/types/definition/{type_name}/{version}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTemplateByDeviceType(self, deviceType):
        """
        Generate template based on device
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        deviceType	 (string):	Device type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/{deviceType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editFeatureTemplate(self, template, templateId):
        """
        Update feature template
        NOTE: In a multitenant vManage system, this API is only available in the Provider view.
        
        Parameters:
        template:	Template
		templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/{templateId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, template)
        return response


    def deleteGeneralTemplate(self, templateId):
        """
        Delete feature template
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/feature/{templateId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getEncryptedString(self, type6encryption):
        """
        Get Type 6 Encryptedd String for a given value
        
        Parameters:
        type6encryption:	Type6 Encryption
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/security/encryptText/encrypt"
        response = self.client.apiCall(HttpMethods.POST, endpoint, type6encryption)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Cloud(object):
    """
    System - Cloud Service API
    
    Implements GET POST DEL PUT methods for CloudService endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAccessTokenforDevice(self):
        """
        getAccessTokenforDevice Description
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/accesstoken"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAzureToken(self, bodyParameter):
        """
        Get Azure token
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/authtoken"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def connect(self):
        """
        Telemetry Opt In
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/connect"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudCreds(self):
        """
        Get cloud service credentials
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/credentials"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def addCloudCreds(self, bodyParameter):
        """
        Get cloud service settings
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/credentials"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def getDeviceCode(self):
        """
        Get Azure device code
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/devicecode"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def isStaging(self):
        """
        Check if testbed or production
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/staging"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTelemetryState(self):
        """
        Get Telemetry state
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/telemetry"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def optIn(self, bodyParameter):
        """
        Telemetry Opt In
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/telemetry/optin"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, bodyParameter)
        return response


    def optOut(self, bodyParameter):
        """
        Telemetry Opt Out
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/cloudservices/telemetry/optout"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, bodyParameter)
        return response


    def getCloudSettings(self):
        """
        Get cloud service settings
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getOTP(self):
        """
        Get cloud service OTP value
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/otp"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updatetOTP(self, cloudserviceotpvalue):
        """
        Update cloud service OTP value
        
        Parameters:
        cloudserviceotpvalue:	Cloud service OTP value
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/dca/cloudservices/otp"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, cloudserviceotpvalue)
        return response


    def listEntityOwnerInfo(self):
        """
        List all entity ownership info
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/entityownership/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def entityOwnerInfo(self):
        """
        Entity ownership info grouped by buckets
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/entityownership/tree"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Orchestrator(object):
    """
    Real-Time Monitoring - Orchestrator API
    
    Implements GET POST DEL PUT methods for Orchestrator endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getConnList(self, deviceId):
        """
        Get connection list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/connections?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConnHist(self, deviceId):
        """
        Get connection history list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/connectionshistory?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLocalProperties(self, deviceId):
        """
        Get local properties list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/localproperties?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRevProxy(self, deviceId):
        """
        Get reverse proxy mapping from vbond
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/proxymapping?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStats(self, deviceId):
        """
        Get statistics from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/statistics?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConnSummary(self, deviceId):
        """
        Get connection summary from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getValidDevicesList(self, deviceId):
        """
        Get valid device list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/validvedges?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getValidVManageId(self, deviceId):
        """
        Get valid vManage Id from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/validvmanageid?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getValidVSmartsList(self, deviceId):
        """
        Get valid vSmart list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/orchestrator/validvsmarts?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class IPsec(object):
    """
    Real-Time Monitoring - IPsec API
    
    Implements GET POST DEL PUT methods for IPsec endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def createCryptoIpsecIdentity(self, rTlocAddr, rTlocColor, lTlocColor, deviceId):
        """
        Get Crypto IPSEC identity entry from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		lTlocColor	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/identity?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIkeInboundList(self, deviceId):
        """
        Get IPsec IKE inbound connection list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/ike/inbound?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIkeOutboundList(self, deviceId):
        """
        Get IPsec IKE outbound connection list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/ike/outbound?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIkeSessions(self, rTlocAddr, rTlocColor, deviceId):
        """
        Get IPsec IKE sessions from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/ike/sessions?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createCryptov1LocalSAList(self, rTlocAddr, rTlocColor, deviceId):
        """
        Get Crypto IKEv1 SA entry from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/ikev1?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createCryptov2LocalSAList(self, deviceId):
        """
        Get Crypto IKEv2 SA entry from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/ikev2?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createInBoundList(self, rTlocAddr, rTlocColor, lTlocColor, deviceId):
        """
        Get IPsec inbound connection list from device (Real Time)
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		lTlocColor	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/inbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createLocalSAList(self, deviceId):
        """
        Get IPsec local SA list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/localsa?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createOutBoundList(self, rTlocAddr, rTlocColor, deviceId):
        """
        Get IPsec outbound connection list from device (Real Time)
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/outbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIPsecPWKInboundConnections(self, rTlocAddr, rTlocColor, lTlocColor, deviceId):
        """
        Get IPSEC pairwise key inbound entry from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		lTlocColor	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/pwk/inbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIPsecPWKLocalSA(self, rTlocAddr, rTlocColor, lTlocColor, deviceId):
        """
        Get IPSEC pairwise key local SA  entry from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		lTlocColor	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/pwk/localsa?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIPsecPWKOutboundConnections(self, rTlocAddr, rTlocColor, lTlocColor, deviceId):
        """
        Get IPSEC pairwise key outbound entry from device
        
        Parameters:
        rTlocAddr	 (string):	Remote TLOC address
		rTlocColor	 (string):	Remote tloc color
		lTlocColor	 (string):	Local tloc color
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ipsec/pwk/outbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class SoftwareActions(object):
    """
    Configuration - Software Actions API
    
    Implements GET POST DEL PUT methods for Software Actions endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def findSoftwareImages(self):
        """
        Get software images
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createImageURL(self, payload):
        """
        Create software image URL
        
        Parameters:
        payload:	Create software image request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getImageProps(self, versionId):
        """
        Get Image Properties
        
        Parameters:
        versionId	 (string):	Version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/imageProperties/{versionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findImagesWithFilters(self, imageType, vnfType):
        """
        Get software images
        
        Parameters:
        imageType	 (string):	Image type
		vnfType	 (string):	VNF type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/images?imageType={imageType}&vnfType={vnfType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPnfProperties(self, pnfType):
        """
        Get PNF Properties
        
        Parameters:
        pnfType	 (string):	PNF type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/pnfproperties/{pnfType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findVEdgeSoftwareVersion(self):
        """
        Get vEdge software version
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/vedge/version"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findSoftwareVersion(self):
        """
        Get software version
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/version"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVnfProperties(self, versionId):
        """
        Get VNF Properties
        
        Parameters:
        versionId	 (string):	Version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/vnfproperties/{versionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def findZtpSoftwareVersion(self):
        """
        Get ZTP software version
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/ztp/version"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateImageURL(self, payload, versionId):
        """
        Update software image URL
        
        Parameters:
        payload:	Update software image request payload
		versionId	 (string):	Version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/{versionId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, payload)
        return response


    def deleteImageURL(self, versionId):
        """
        Delete software image URL
        
        Parameters:
        versionId	 (string):	Version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/software/{versionId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class CloudOnRamp(object):
    """
    Configuration - Cloud On Ramp API
    
    Implements GET POST DEL PUT methods for CloudOnRamp endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCORStatus(self):
        """
        Get Cloud On Ramp list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createAndMap(self, request):
        """
        Map Host to Transit VPC/VNet
        
        Parameters:
        request:	Map host to transit VPC request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def raiseAlarmForAccount(self, accountobject):
        """
        Raise alarm for account
        
        Parameters:
        accountobject:	Account object
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/account/alarm"
        response = self.client.apiCall(HttpMethods.POST, endpoint, accountobject)
        return response


    def removeTransitVPC(self, accountid, transitvpcid, cloudregion, cloudtype):
        """
        Delete transit VPC/VNet
        
        Parameters:
        accountid	 (string):	Account Id
		transitvpcid	 (string):	Cloud VPC Id
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/accountid/{accountid}?transitvpcid={transitvpcid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def acquireRP(self, request):
        """
        Acquire IP from resource pool
        
        Parameters:
        request:	Add IP from resource pool request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/acquireResourcePool"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def getAmiList(self, accountid, cloudregion, cloudtype):
        """
        Get AMI list
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/ami?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudList(self):
        """
        Get cloud list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudAccounts(self, cloudtype, cloudEnvironment):
        """
        Get cloud accounts
        
        Parameters:
        cloudtype	 (string):	Cloud type
		cloudEnvironment	 (string):	Cloud environment
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud/account?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def authCredAndUpdate(self, credential):
        """
        Authenticate and update cloud account credentials
        
        Parameters:
        credential:	Cloud account credential
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud/authenticate"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, credential)
        return response


    def authCORCredAndAdd(self, credential):
        """
        Authenticate cloud account credentials
        
        Parameters:
        credential:	Cloud account credential
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud/authenticate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, credential)
        return response


    def getCloudHostVpcAccountDetails(self):
        """
        Get cloud host VPC account details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud/host/accountdetails"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudMappedHostAccounts(self, accountid, cloudtype):
        """
        Get cloud mapped accounts view
        
        Parameters:
        accountid	 (string):	Account Id
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/cloud/mappedhostaccounts?accountid={accountid}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createRP(self, request):
        """
        Add resource pool
        
        Parameters:
        request:	Add resource pool request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/createResourcePool"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def removeDeviceId(self, accountid, transitvpcid, transitvpcname, cloudregion, cloudtype, devicePairId):
        """
        Remove device pair
        
        Parameters:
        accountid	 (string):	Account Id
		transitvpcid	 (string):	VPC Id
		transitvpcname	 (string):	VPC Name
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
		devicePairId	 (string):	Device pair Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/deleteDevicepair?accountid={accountid}&transitvpcid={transitvpcid}&transitvpcname={transitvpcname}&cloudregion={cloudregion}&cloudtype={cloudtype}&devicePairId={devicePairId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getCORDevices(self):
        """
        Get available device list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/device"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def addDevicePair(self, request):
        """
        Add device pair
        
        Parameters:
        request:	Add device pair request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/devicepair"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def getHostVPCs(self, transitVpcId, devicePairId):
        """
        Get host VPC details
        
        Parameters:
        transitVpcId	 (string):	Transit VPC Id
		devicePairId	 (string):	Device pair Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/devicepair/hostvpc?transitVpcId={transitVpcId}&devicePairId={devicePairId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getExternalId(self):
        """
        Get the vManage external ID for AWS
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/externalId"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTransitDevicePairAndHostList(self, accountId, cloudRegion):
        """
        Get device and host details
        
        Parameters:
        accountId	 (string):	Account Id
		cloudRegion	 (string):	Cloud region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/getTransitDevicePairAndHostList?accountId={accountId}&cloudRegion={cloudRegion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTransitVpcVpnList(self, accountId):
        """
        Get transit VPN list
        
        Parameters:
        accountId	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/getTransitVpnList?accountId={accountId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudHostVPCs(self, accountid, cloudregion, cloudtype):
        """
        Get host VPC/VNet list
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/hostvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTenantAndHostVpcList(self, intent):
        """
        Get tenant and host VPC list
        
        Parameters:
        intent	 (string):	Intent
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/hostvpclist?intent={intent}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateHostVpcReachability(self, updatevpcstatus):
        """
        Update host VPC reachability
        
        Parameters:
        updatevpcstatus:	Update VPC status
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/hostvpclist"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, updatevpcstatus)
        return response


    def getMappedVPCs(self, accountid, cloudregion):
        """
        Get mapped VPC/VNet list
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/map?accountid={accountid}&cloudregion={cloudregion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def mapVPCs(self, host):
        """
        Map host to transit VPC/VNet
        
        Parameters:
        host:	Map host to VPC/VNet
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/map"
        response = self.client.apiCall(HttpMethods.POST, endpoint, host)
        return response


    def unmapVPCs(self, host):
        """
        Unmap host from transit VPC/VNet
        
        Parameters:
        host:	Unmap host to VPC/VNet
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/map"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, host)
        return response


    def getPemKeyList(self, accountid, cloudregion, cloudtype):
        """
        Get transit VPC PEM key list
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/pem?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def scaleDown(self, updatevpc):
        """
        Scale down cloud on ramp
        
        Parameters:
        updatevpc:	Update VPC
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/scale/down"
        response = self.client.apiCall(HttpMethods.POST, endpoint, updatevpc)
        return response


    def scaleUp(self, updatevpc):
        """
        Scale up cloud on ramp
        
        Parameters:
        updatevpc:	Update VPC
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/scale/up"
        response = self.client.apiCall(HttpMethods.POST, endpoint, updatevpc)
        return response


    def updatestatus(self, statusobject):
        """
        Update task status
        
        Parameters:
        statusobject:	Status object
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/status"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statusobject)
        return response


    def getTransitVPCs(self, accountid, cloudregion, cloudtype):
        """
        Get transit VPC/VNet list
        
        Parameters:
        accountid	 (string):	Account Id
		cloudregion	 (string):	Cloud region
		cloudtype	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/transitvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateTransitVPC(self, vpc):
        """
        Update transit VPC/VNet
        
        Parameters:
        vpc:	VPC
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/transitvpc"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, vpc)
        return response


    def addTransitVPC(self, vpc):
        """
        Create transit VPC/VNet
        
        Parameters:
        vpc:	VPC
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/transitvpc"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vpc)
        return response


    def updateTransitVpcAutoscaleProperties(self, vpc):
        """
        Update transit VPC autoscale properties
        
        Parameters:
        vpc:	VPC
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/transitvpc/autoscale-properties"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, vpc)
        return response


    def getTransitVPCSupportedSize(self, cloudtype, cloudEnvironment):
        """
        Get transit VPC supported size
        
        Parameters:
        cloudtype	 (string):	Cloud type
		cloudEnvironment	 (string):	Cloud environment
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cor/transitvpc/size?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Design(object):
    """
    Configuration - Network Design Templates API
    
    Implements GET POST DEL PUT methods for NetworkDesignTemplates endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getGlobal(self, templateId):
        """
        Get global template
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/global/template/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editGlobal(self, globaltemplate, templateId):
        """
        Edit global template
        
        Parameters:
        globaltemplate:	Global template
		templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/global/template/{templateId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, globaltemplate)
        return response


    def getFeatureTempList(self):
        """
        Generate device profile template list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/feature"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProfileList(self):
        """
        Generate profile template list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/template"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceProfile(self, templateId):
        """
        Get device profile template
        
        Parameters:
        templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/template/{templateId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editDeviceProfile(self, globaltemplate, templateId):
        """
        Edit device profile template
        
        Parameters:
        globaltemplate:	Global template
		templateId	 (string):	Template Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/networkdesign/profile/template/{templateId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, globaltemplate)
        return response





import json

class Parser(object):
    @staticmethod
    def parseResponse(response):
        try:
            raw_data = json.loads(response.text)
        except:
            raw_data = {'error':"could not parse response"}
        if 'data' in raw_data:
            parsed_data = raw_data['data']
        else:
            parsed_data = raw_data
        return parsed_data


from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Aar(object):
    """
    Monitoring - Application Aware Routing API
    
    Implements GET POST DEL PUT methods for ApplicationAwareRouting endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPostAggregationAppDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getApprouteGridStat(self, query):
        """
        Get statistics for top applications per tunnel in a grid table
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/device/tunnel/summary?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTunnel(self, query):
        """
        Get statistics for top applications per tunnel in a grid table
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/device/tunnels?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataAppRoute(self, queryfilter):
        """
        Get aggregation data and fec recovery rate
        
        Parameters:
        queryfilter:	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/fec/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, queryfilter)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTunnelChart(self, type, query):
        """
        Get tunnel top statistics in as chart
        
        Parameters:
        type	 (string):	Type
		query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/tunnel/{type}/summary?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTunnelsSummary(self, type, query, limit):
        """
        Get tunnel top statistics from device
        
        Parameters:
        type	 (string):	Type
		query	 (string):	Query filter
		limit	 (integer):	Query result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/tunnels/summary/{type}?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTunnels(self, type, query, limit):
        """
        Get tunnel top statistics from device
        
        Parameters:
        type	 (string):	Type
		query	 (string):	Query filter
		limit	 (integer):	Query result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/approute/tunnels/{type}?query={query}&limit={limit}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class CloudExpress(object):
    """
    Configuration - CloudExpress API
    
    Implements GET POST DEL PUT methods for CloudExpress endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getCloudXStatus(self):
        """
        Get CloudX feature list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def addCloudxType(self, cloudx, type):
        """
        Add cloudx gateway
        
        Parameters:
        cloudx:	Cloudx
		type	 (string):	Cloudx type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/addcloudx/{type}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, cloudx)
        return response


    def getAttachedClientList(self):
        """
        Get attached client site list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/attachedclient"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAttachedDiaList(self):
        """
        Get attached Dia site list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/attacheddia"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAttachedGwList(self):
        """
        Get attached gateway list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/attachedgateway"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudXAvailableApps(self):
        """
        Get CloudX available apps list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/availableapps"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSiteList(self):
        """
        Get site list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/clientlist"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDiaList(self):
        """
        Get Dia site list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/dialist"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getGwList(self):
        """
        Get gateway list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/gatewaylist"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def addCloudxInterfaces(self, cloudx):
        """
        Enable cloudx gateway
        
        Parameters:
        cloudx:	Cloudx
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/interfaces"
        response = self.client.apiCall(HttpMethods.POST, endpoint, cloudx)
        return response


    def getApps(self):
        """
        Get apps and vpns
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/manage/apps"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editApps(self, appVPN):
        """
        Edit apps and vpns
        
        Parameters:
        appVPN:	Cloudx apps and vpns
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/manage/apps"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, appVPN)
        return response


    def addApps(self, appVPN):
        """
        Add apps and vpns
        
        Parameters:
        appVPN:	Cloudx apps and vpns
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/manage/apps"
        response = self.client.apiCall(HttpMethods.POST, endpoint, appVPN)
        return response


    def sitePerApp(self, appName, vpnId):
        """
        Get sites per application per vpn
        
        Parameters:
        appName	 (string):	App name
		vpnId	 (integer):	VPN Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/cloudx/status?appName={appName}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Neighbor(object):
    """
    Real-Time Monitoring - IPv6 Neighbours API
    
    Implements GET POST DEL PUT methods for IPv6Neighbours endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getInterface(self, vpnId, ifname, mac, deviceId):
        """
        Get IPv6 Neighbors from device (Real Time)
        
        Parameters:
        vpnId	        (string):	VPN Id
		ifname	        (string):	Interface name
		mac	            (string):	Mac address
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/ndv6?vpn-id={vpnId}&if-name={ifname}&mac={mac}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DNAC(object):
    """
    Partner - DNAC SDA API API
    
    Implements GET POST DEL PUT methods for DNACSDAAPI endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def createSDAConfig(self, config, partnerId):
        """
        Create SDA enabled device
        
        Parameters:
        config:	Device SDA configuration
		partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/config/{partnerId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, config)
        return response


    def getSDAEnabledDevices(self, partnerId):
        """
        Get SDA enabled devices
        
        Parameters:
        partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/device/{partnerId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceDetails(self, partnerId, uuid):
        """
        Get SDA enabled devices detail
        
        Parameters:
        partnerId	 (string):	Partner Id
		uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/device/{partnerId}/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createSDAConfigFromNetconf(self, config, partnerId):
        """
        Create SDA enabled device from Netconf
        
        Parameters:
        config:	Device SDA configuration
		partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/netconfconfig/{partnerId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, config)
        return response


    def getSitesForPartner(self, partnerId):
        """
        Get SDA enabled devices
        
        Parameters:
        partnerId	 (string):	Partner Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/site/{partnerId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getOverlayVPNList(self):
        """
        Get Overlay VPN list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/dnac/sda/vpn"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DeviceSharing(object):
    """
    MDP - Device Sharing API
    
    Implements GET POST DEL PUT methods for Device Sharing endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getAttached(self, nmsId):
        """
        Retrieve MDP attached devices
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/attachDevices/{nmsId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editAttached(self, devicelist, nmsId):
        """
        Edit attached devices
        
        Parameters:
        devicelist:	deviceList
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/attachDevices/{nmsId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, devicelist)
        return response


    def attach(self, devicelist, nmsId):
        """
        Share devices with MDP
        
        Parameters:
        devicelist:	deviceList
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/attachDevices/{nmsId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def detach(self, devicelist, nmsId):
        """
        Disconnect devices from mpd controller
        
        Parameters:
        devicelist:	deviceList
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/detachDevices/{nmsId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def getSupported(self, nmsId):
        """
        Retrieve MDP supported devices
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/mdp/devices/{nmsId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Segments(object):
    """
    Configuration - Segments API
    
    Implements GET POST DEL PUT methods for Segments endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getSegments(self):
        """
        Get network segments
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/segment"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createSegment(self, segmen):
        """
        Create network segment
        
        Parameters:
        segmen:	Network segment
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/segment"
        response = self.client.apiCall(HttpMethods.POST, endpoint, segmen)
        return response


    def getSegment(self, id):
        """
        Get network segment
        
        Parameters:
        id	 (string):	Segment Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/segment/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editSegment(self, segmen, id):
        """
        Edit network segment
        
        Parameters:
        segmen:	Network segment
		id	 (string):	Segment Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/segment/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, segmen)
        return response


    def deleteSegment(self, id):
        """
        Delete network segment
        
        Parameters:
        id	 (string):	Segment Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/segment/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


